/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CustomFieldOptionObject } from "../definitions/CustomFieldOptionObject";
export interface CustomFieldObject {
    /**
     * If true, this field is available for use
     */
    active?: boolean;
    /**
     * Required and presented for a custom field of type "dropdown". Each option is represented by an object with a `name` and `value` property
     */
    custom_field_options?: Array<CustomFieldOptionObject>;
    /**
     * User-defined description of this field's purpose
     */
    description?: string;
    /**
     * A unique key that identifies this custom field. This is used for updating the field and referencing in placeholders. The key must consist of only letters, numbers, and underscores. It can't be only numbers
     */
    key: string;
    /**
     * Ordering of the field relative to other fields
     */
    position?: number;
    /**
     * The dynamic content placeholder, if present, or the `description` value, if not. See [Dynamic Content Items](/api-reference/ticketing/ticket-management/dynamic_content/)
     */
    raw_description?: string;
    /**
     * The dynamic content placeholder, if present, or the `title` value, if not. See [Dynamic Content Items](/api-reference/ticketing/ticket-management/dynamic_content/)
     */
    raw_title?: string;
    /**
     * Regular expression field only. The validation pattern for a field value to be deemed valid
     */
    regexp_for_validation?: string;
    /**
     * A filter definition that allows your autocomplete to filter down results
     */
    relationship_filter?: any;
    /**
     * A representation of what type of object the field references. Options are "zen:user", "zen:organization", "zen:ticket", and "zen:custom_object:{key}" where key is a custom object key. For example "zen:custom_object:apartment".
     */
    relationship_target_type?: string;
    /**
     * Optional for custom field of type "checkbox"; not presented otherwise.
     */
    tag?: string;
    /**
     * The title of the custom field
     */
    title: string;
    /**
     * The custom field type: "checkbox", "date", "decimal", "dropdown", "integer", ["lookup"](/api-reference/ticketing/lookup_relationships/lookup_relationships/), "multiselect", "regexp", "text", or "textarea"
     */
    type: string;
}
//# sourceMappingURL=CustomFieldObject.d.ts.map