/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CollaboratorObjectAsResponse } from "../definitions/CollaboratorObjectAsResponse";
export interface TicketObjectAsResponse {
    /**
     * Permission for agents to add add attachments to a comment. Defaults to true
     */
    allow_attachments?: boolean;
    /**
     * Is false if channelback is disabled, true otherwise. Only applicable for channels framework ticket
     */
    allow_channelback?: boolean;
    /**
     * The agent currently assigned to the ticket
     */
    assignee_id?: number;
    /**
     * The id of the brand this ticket is associated with. See [Setting up multiple brands](https://support.zendesk.com/hc/en-us/articles/4408829476378)
     */
    brand_id?: number;
    /**
     * The ids of users currently CC'ed on the ticket
     */
    collaborator_ids?: Array<number>;
    /**
     * POST requests only. Users to add as cc's when creating a ticket. See [Setting Collaborators](/documentation/ticketing/managing-tickets/creating-and-updating-tickets#setting-collaborators)
     */
    collaborators?: Array<CollaboratorObjectAsResponse>;
    /**
     * When this record was created
     */
    created_at?: string;
    /**
     * Custom fields for the ticket. See [Setting custom field values](/documentation/ticketing/managing-tickets/creating-and-updating-tickets#setting-custom-field-values)
     */
    custom_fields?: Array<{
        /**
         * The id of the custom field
         */
        id?: number;
        /**
         * The value of the custom field
         */
        value?: string;
    }>;
    /**
     * The custom ticket status id of the ticket. See [custom ticket statuses](#custom-ticket-statuses)
     */
    custom_status_id?: number;
    /**
  * Read-only first comment on the ticket. When [creating a ticket](#create-ticket), use `comment` to set the description. See [Description and first comment](#description-and-first-comment)
  
  */
    description?: string;
    /**
     * If this is a ticket of type "task" it has a due date.  Due date format uses [ISO 8601](http://en.wikipedia.org/wiki/ISO_8601) format
     */
    due_at?: string;
    /**
     * The ids of agents or end users currently CC'ed on the ticket. See [CCs and followers resources](https://support.zendesk.com/hc/en-us/articles/360020585233) in the Support Help Center
     */
    email_cc_ids?: Array<number>;
    /**
     * An id you can use to link Zendesk Support tickets to local records
     */
    external_id?: string;
    /**
     * The ids of agents currently following the ticket. See [CCs and followers resources](https://support.zendesk.com/hc/en-us/articles/360020585233)
     */
    follower_ids?: Array<number>;
    /**
     * The ids of the followups created from this ticket. Ids are only visible once the ticket is closed
     */
    followup_ids?: Array<number>;
    /**
     * The topic in the Zendesk Web portal this ticket originated from, if any. The Web portal is deprecated
     */
    forum_topic_id?: number;
    /**
     * If true, the ticket's [via type](/documentation/ticketing/reference-guides/via-object-reference/) is a messaging channel.
     */
    from_messaging_channel?: boolean;
    /**
     * A Unix timestamp that represents the most accurate reading of when this record was last updated. It is updated for all ticket updates, including system updates
     */
    generated_timestamp?: number;
    /**
     * The group this ticket is assigned to
     */
    group_id?: number;
    /**
     * Is true if a ticket is a problem type and has one or more incidents linked to it. Otherwise, the value is false.
     */
    has_incidents?: boolean;
    /**
     * Automatically assigned when the ticket is created
     */
    id?: number;
    /**
     * Is true if any comments are public, false otherwise
     */
    is_public?: boolean;
    /**
     * POST requests only. List of macro IDs to be recorded in the ticket audit
     */
    macro_ids?: Array<number>;
    /**
     * The organization of the requester. You can only specify the ID of an organization associated with the requester. See [Organization Memberships](/api-reference/ticketing/organizations/organization_memberships/)
     */
    organization_id?: number;
    /**
     * The urgency with which the ticket should be addressed
     */
    priority?: "urgent" | "high" | "normal" | "low";
    /**
     * For tickets of type "incident", the ID of the problem the incident is linked to
     */
    problem_id?: number;
    /**
  * The dynamic content placeholder, if present, or the "subject" value, if not. See [Dynamic Content Items](/api-reference/ticketing/ticket-management/dynamic_content/)
  
  */
    raw_subject?: string;
    /**
     * The original recipient e-mail address of the ticket. Notification emails for the ticket are sent from this address
     */
    recipient?: string;
    /**
     * The user who requested this ticket
     */
    requester_id: number;
    /**
     * The satisfaction rating of the ticket, if it exists, or the state of satisfaction, "offered" or "unoffered". The value is null for plan types that don't support CSAT
     */
    satisfaction_rating?: {
        [x: string]: any;
    };
    /**
     * The ids of the sharing agreements used for this ticket
     */
    sharing_agreement_ids?: Array<number>;
    /**
  * The state of the ticket.
  
  If your account has activated custom ticket statuses, this is the ticket's
  status category. See [custom ticket statuses](#custom-ticket-statuses)
  
  */
    status?: "new" | "open" | "pending" | "hold" | "solved" | "closed";
    /**
  * The value of the subject field for this ticket. See [Subject](/api-reference/ticketing/tickets/tickets/#subject)
  
  */
    subject?: string;
    /**
     * The user who submitted the ticket. The submitter always becomes the author of the first comment on the ticket
     */
    submitter_id?: number;
    /**
     * The array of tags applied to this ticket. Unless otherwise specified, the [set tag](/api-reference/ticketing/ticket-management/tags/#set-tags) behavior is used, which overwrites and replaces existing tags
     */
    tags?: Array<string>;
    /**
     * Enterprise only. The id of the ticket form to render for the ticket
     */
    ticket_form_id?: number;
    /**
     * The type of this ticket
     */
    type?: "problem" | "incident" | "question" | "task";
    /**
     * When this record last got updated. It is updated only if the update generates a [ticket event](#incremental-ticket-event-export)
     */
    updated_at?: string;
    /**
     * The API url of this ticket
     */
    url?: string;
    /**
     * For more information, see the [Via object reference](/documentation/ticketing/reference-guides/via-object-reference)
     */
    via?: {
        /**
    * This tells you how the ticket or event was created. Examples: "web", "mobile", "rule", "system"
    
    */
        channel?: string;
        /**
    * For some channels a source object gives more information about how or why the ticket or event was created
    
    */
        source?: {
            [x: string]: any;
        };
    };
    /**
     * POST requests only. The id of a closed ticket when creating a follow-up ticket. See [Creating a follow-up ticket](/documentation/ticketing/managing-tickets/creating-and-updating-tickets#creating-a-follow-up-ticket)
     */
    via_followup_source_id?: number;
}
//# sourceMappingURL=TicketObjectAsResponse.d.ts.map