/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CollaboratorObject } from "../definitions/CollaboratorObject";
import { TicketCommentObject } from "../definitions/TicketCommentObject";
import { CustomFieldObject } from "../definitions/CustomFieldObject";
import { EmailCCObject } from "../definitions/EmailCCObject";
import { FollowerObject } from "../definitions/FollowerObject";
export interface TicketUpdateInput {
    /**
     * An array of numeric IDs, emails, or objects containing name and email properties. See [Setting Collaborators](/api-reference/ticketing/tickets/tickets/#setting-collaborators). An email notification is sent to them when the ticket is updated
     */
    additional_collaborators?: Array<CollaboratorObject>;
    /**
     * The email address of the agent to assign the ticket to
     */
    assignee_email?: string;
    /**
     * The agent currently assigned to the ticket
     */
    assignee_id?: number;
    /**
     * An array of the IDs of attribute values to be associated with the ticket
     */
    attribute_value_ids?: Array<number>;
    /**
     * The ids of users currently CC'ed on the ticket
     */
    collaborator_ids?: Array<number>;
    comment?: TicketCommentObject;
    /**
     * Custom fields for the ticket. See [Setting custom field values](/documentation/ticketing/managing-tickets/creating-and-updating-tickets#setting-custom-field-values)
     */
    custom_fields?: Array<CustomFieldObject>;
    /**
     * The custom ticket status id of the ticket. See [custom ticket statuses](#custom-ticket-statuses)
     */
    custom_status_id?: number;
    /**
     * If this is a ticket of type "task" it has a due date.  Due date format uses [ISO 8601](http://en.wikipedia.org/wiki/ISO_8601) format.
     */
    due_at?: string;
    /**
     * An array of objects that represent agent or end users email CCs to add or delete from the ticket. See [Setting email CCs](/documentation/ticketing/managing-tickets/creating-and-updating-tickets#setting-email-ccs)
     */
    email_ccs?: Array<EmailCCObject>;
    /**
     * An id you can use to link Zendesk Support tickets to local records
     */
    external_id?: string;
    /**
     * An array of objects that represent agent followers to add or delete from the ticket. See [Setting followers](/documentation/ticketing/managing-tickets/creating-and-updating-tickets#setting-followers)
     */
    followers?: Array<FollowerObject>;
    /**
     * The group this ticket is assigned to
     */
    group_id?: number;
    /**
     * The organization of the requester. You can only specify the ID of an organization associated with the requester. See [Organization Memberships](/api-reference/ticketing/organizations/organization_memberships/)
     */
    organization_id?: number;
    /**
     * The urgency with which the ticket should be addressed.
     */
    priority?: "urgent" | "high" | "normal" | "low";
    /**
     * For tickets of type "incident", the ID of the problem the incident is linked to
     */
    problem_id?: number;
    /**
     * The user who requested this ticket
     */
    requester_id?: number;
    /**
     * Optional boolean. Prevents updates with outdated ticket data (`updated_stamp` property required when true)
     */
    safe_update?: boolean;
    /**
     * An array of the numeric IDs of sharing agreements. Note that this replaces any existing agreements
     */
    sharing_agreement_ids?: Array<number>;
    /**
  * The state of the ticket.
  
  If your account has activated custom ticket statuses, this is the ticket's
  status category. See [custom ticket statuses](#custom-ticket-statuses).
  
  */
    status?: "new" | "open" | "pending" | "hold" | "solved" | "closed";
    /**
     * The value of the subject field for this ticket
     */
    subject?: string;
    /**
     * The array of tags applied to this ticket
     */
    tags?: Array<string>;
    /**
     * The type of this ticket.
     */
    type?: "problem" | "incident" | "question" | "task";
    /**
     * Datetime of last update received from API. See the safe_update property
     */
    updated_stamp?: string;
}
//# sourceMappingURL=TicketUpdateInput.d.ts.map