/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
export interface UserForAdminAsResponse {
    /**
     * false if the user has been deleted
     */
    active?: boolean;
    /**
     * An alias displayed to end users
     */
    alias?: string;
    /**
     * Whether or not the user is a chat-only agent
     */
    chat_only?: boolean;
    /**
     * The time the user was created
     */
    created_at?: string;
    /**
     * A custom role if the user is an agent on the Enterprise plan or above
     */
    custom_role_id?: number;
    /**
     * The id of the user's default group
     */
    default_group_id?: number;
    /**
     * Any details you want to store about the user, such as an address
     */
    details?: string;
    /**
     * The user's primary email address. *Writeable on create only. On update, a secondary email is added. See [Email Address](#email-address)
     */
    email?: string;
    /**
     * A unique identifier from another system. The API treats the id as case insensitive. Example: "ian1" and "IAN1" are the same value.
     */
    external_id?: string;
    /**
     * The time zone for the user
     */
    iana_time_zone?: string;
    /**
     * Automatically assigned when the user is created
     */
    id?: number;
    /**
  * Last time the user signed in to Zendesk Support or made an API request
  using an API token or basic authentication
  
  */
    last_login_at?: string;
    /**
     * The user's locale. A BCP-47 compliant tag for the locale. If both "locale" and "locale_id" are present on create or update, "locale_id" is ignored and only "locale" is used.
     */
    locale?: string;
    /**
     * The user's language identifier
     */
    locale_id?: number;
    /**
     * Designates whether the user has forum moderation capabilities
     */
    moderator?: boolean;
    /**
     * The user's name
     */
    name: string;
    /**
     * Any notes you want to store about the user
     */
    notes?: string;
    /**
     * true if the user can only create private comments
     */
    only_private_comments?: boolean;
    /**
     * The id of the user's organization. If the user has more than one [organization memberships](/api-reference/ticketing/organizations/organization_memberships/), the id of the user's default organization. If updating, see [Organization ID](#organization-id)
     */
    organization_id?: number;
    /**
     * The user's primary phone number. See [Phone Number](#phone-number) below
     */
    phone?: string;
    /**
     * The user's profile picture represented as an [Attachment](/api-reference/ticketing/tickets/ticket-attachments/) object
     */
    photo?: {
        [x: string]: any;
    };
    /**
     * A URL pointing to the user's profile picture.
     */
    remote_photo_url?: string;
    /**
  * This parameter is inert and has no effect. It may be deprecated in the
  future.
  
  Previously, this parameter determined whether a user could access a CSV
  report in a legacy Guide dashboard. This dashboard has been removed. See
  [Announcing Guide legacy reporting upgrade to
  Explore](https://support.zendesk.com/hc/en-us/articles/4762263171610-Announcing-Guide-legacy-reporting-upgrade-to-Explore-)
  
  */
    report_csv?: boolean;
    /**
     * If the agent has any restrictions; false for admins and unrestricted agents, true for other agents
     */
    restricted_agent?: boolean;
    /**
     * The user's role. Possible values are "end-user", "agent", or "admin"
     */
    role?: string;
    /**
     * The user's role id. 0 for a custom agent, 1 for a light agent, 2 for a chat agent, 3 for a chat agent added to the Support account as a contributor ([Chat Phase 4](https://support.zendesk.com/hc/en-us/articles/360022365373#topic_djh_1zk_4fb)), 4 for an admin, and 5 for a billing admin
     */
    role_type?: number;
    /**
     * If the user is shared from a different Zendesk Support instance. Ticket sharing accounts only
     */
    shared?: boolean;
    /**
     * If the user is a shared agent from a different Zendesk Support instance. Ticket sharing accounts only
     */
    shared_agent?: boolean;
    /**
     * Whether the `phone` number is shared or not. See [Phone Number](#phone-number) below
     */
    shared_phone_number?: boolean;
    /**
     * The user's signature. Only agents and admins can have signatures
     */
    signature?: string;
    /**
     * If the agent is suspended. Tickets from suspended users are also suspended, and these users cannot sign in to the end user portal
     */
    suspended?: boolean;
    /**
     * The user's tags. Only present if your account has user tagging enabled
     */
    tags?: Array<string>;
    /**
     * Specifies which tickets the user has access to. Possible values are: "organization", "groups", "assigned", "requested", null. "groups" and "assigned" are valid only for agents. If you pass an invalid value to an end user (for example, "groups"), they will be assigned to "requested", regardless of their previous access
     */
    ticket_restriction?: string;
    /**
     * The user's time zone. See [Time Zone](#time-zone)
     */
    time_zone?: string;
    /**
     * If two factor authentication is enabled
     */
    two_factor_auth_enabled?: boolean;
    /**
     * The time the user was last updated
     */
    updated_at?: string;
    /**
     * The user's API url
     */
    url?: string;
    /**
     * Values of custom fields in the user's profile. See [User Fields](#user-fields)
     */
    user_fields?: {
        [x: string]: any;
    };
    /**
     * Any of the user's identities is verified. See [User Identities](/api-reference/ticketing/users/user_identities)
     */
    verified?: boolean;
}
//# sourceMappingURL=UserForAdminAsResponse.d.ts.map