/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Blob } from "@managed-api/commons-core";
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class ZenDeskApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Organization = new OrganizationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Group = new GroupGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Ticket = new TicketGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.User, this.Organization, this.Group, this.Ticket);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...((_a = this.options) !== null && _a !== void 0 ? _a : {}),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(User, Organization, Group, Ticket) {
        this.User = User;
        this.Organization = Organization;
        this.Group = Group;
        this.Ticket = Ticket;
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Admins, Agents and Light Agents
    
  * Alternative usage: User.getAllUsers
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#list-users
  * @param options Request options.
  */
    async getAllUsers(options) {
        return this.User.getAllUsers(options);
    }
    /**
  * The endpoint returns [user information](/api-reference/ticketing/users/users/) and an `authenticity_token`.
  
  #### Allowed For
  
  * Anonymous users
  
  #### Authenticity Token
  
  Zendesk API calls made by end users from a Zendesk help center must include `authenticity_token` in the `X-CSRF-Token` HTTP header. This helps prevent [cross-site request forgery (CSRF)](https://en.wikipedia.org/wiki/Cross-site_request_forgery) attacks.
  
  For an example using an authenticity token, see the AJAX request in the [Upgrading from Templating API v1](https://developer.zendesk.com/documentation/help_center/help-center-templates/v1#jquery) documentation.
    
  * Alternative usage: User.getMyUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#show-self
  * @param options Request options.
  */
    async getMyUser(options) {
        return this.User.getMyUser(options);
    }
    /**
  * Accepts a comma-separated list of up to 100 user ids or external ids.
  
  #### Allowed For:
  
  * Agents
    
  * Alternative usage: User.getUsers
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#show-many-users
  * @param options Request options.
  */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
    /**
  * #### Allowed For
  
  * Agents
    
  * Alternative usage: User.getUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#show-user
  * @param options Request options.
  */
    async getUser(options) {
        return this.User.getUser(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Alternative usage: User.getUsersByGroup
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/groups/group_memberships/#list-memberships
  * @param options Request options.
  */
    async getUsersByGroup(options) {
        return this.User.getUsersByGroup(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents and End users.
    
  * Alternative usage: User.getUsersByOrganization
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/organizations/organization_memberships/#list-memberships
  * @param options Request options.
  */
    async getUsersByOrganization(options) {
        return this.User.getUsersByOrganization(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents, with certain restrictions
  
  If the agent has a custom agent role that restricts their access to only users in their own organization, a 403 Forbidden error is returned. See [Creating custom agent roles](https://support.zendesk.com/hc/en-us/articles/203662026-Creating-custom-roles-and-assigning-agents#topic_cxn_hig_bd) in Zendesk help.
    
  * Alternative usage: Organization.getAllOrganizations
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/organizations/organizations/#list-organizations
  * @param options Request options.
  */
    async getAllOrganizations(options) {
        return this.Organization.getAllOrganizations(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents, with certain restrictions.
  
  If the agent has a custom agent role that restricts their access to only users in their own organization, a 403 Forbidden error is returned. See [Creating custom agent roles](https://support.zendesk.com/hc/en-us/articles/4408882153882-Creating-custom-roles-and-assigning-agents#topic_cxn_hig_bd) in Zendesk help.
    
  * Alternative usage: Organization.getOrganizationsByUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/organizations/organizations/#list-organizations
  * @param options Request options.
  */
    async getOrganizationsByUser(options) {
        return this.Organization.getOrganizationsByUser(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Admins
  * Agents
    
  * Alternative usage: Group.getAllGroups
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/groups/groups/#list-groups
  * @param options Request options.
  */
    async getAllGroups(options) {
        return this.Group.getAllGroups(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Admins and Agents.
    
  * Alternative usage: Group.getGroupsByUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/groups/groups/#list-groups
  * @param options Request options.
  */
    async getGroupsByUser(options) {
        return this.Group.getGroupsByUser(options);
    }
    /**
     * List Tickets
     * Alternative usage: Ticket.getAllTickets
     * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
     * @param options Request options.
     */
    async getAllTickets(options) {
        return this.Ticket.getAllTickets(options);
    }
    /**
     * Create Ticket
     * Alternative usage: Ticket.createTicket
     * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#create-ticket
     * @param options Request options.
     */
    async createTicket(options) {
        return this.Ticket.createTicket(options);
    }
    /**
  * Returns a number of ticket properties though not the ticket comments. To get the comments, use [List Comments](/api-reference/ticketing/tickets/ticket_comments/#list-comments)
  
  #### Allowed For
  * Agents
  * Alternative usage: Ticket.getTicket
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#show-ticket
  * @param options Request options.
  */
    async getTicket(options) {
        return this.Ticket.getTicket(options);
    }
    /**
     * Update Ticket
     * Alternative usage: Ticket.updateTicket
     * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#update-ticket
     * @param options Request options.
     */
    async updateTicket(options) {
        return this.Ticket.updateTicket(options);
    }
    /**
  * #### Allowed For
  
  * Admins
  * Agents with permission to delete tickets
  
  Agent delete permissions are set in Support. See
  [Deleting tickets](https://support.zendesk.com/hc/en-us/articles/203690936)
  in the Support Help Center.
  
  #### Ticket deletion rate limit
  
  You can delete 400 tickets every 1 minute using this endpoint.
  The rate limiting mechanism behaves as described in
  [Rate limits](/api-reference/introduction/rate-limits/) in the API introduction.
  Zendesk recommends that you obey the Retry-After header values.
  To delete many tickets, you may use [Bulk Delete Tickets](/api-reference/ticketing/tickets/tickets/#bulk-delete-tickets).
  * Alternative usage: Ticket.deleteTicket
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#delete-ticket
  * @param options Request options.
  */
    async deleteTicket(options) {
        return this.Ticket.deleteTicket(options);
    }
    /**
  * Accepts a comma-separated list of ticket ids to return.
  
  This endpoint will return up to 100 tickets records.
  
  #### Allowed For
  * Agents
  * Alternative usage: Ticket.getTickets
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#show-multiple-tickets
  * @param options Request options.
  */
    async getTickets(options) {
        return this.Ticket.getTickets(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Alternative usage: Ticket.getTicketsByOrganization
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByOrganization(options) {
        return this.Ticket.getTicketsByOrganization(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Alternative usage: Ticket.getTicketsByRequestedUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByRequestedUser(options) {
        return this.Ticket.getTicketsByRequestedUser(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Alternative usage: Ticket.getTicketsByCCdUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByCCdUser(options) {
        return this.Ticket.getTicketsByCCdUser(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Alternative usage: Ticket.getTicketsByFollowedUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByFollowedUser(options) {
        return this.Ticket.getTicketsByFollowedUser(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Alternative usage: Ticket.getTicketsByAssignedUser
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByAssignedUser(options) {
        return this.Ticket.getTicketsByAssignedUser(options);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Alternative usage: Ticket.getRecentTickets
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getRecentTickets(options) {
        return this.Ticket.getRecentTickets(options);
    }
    /**
     * Uploads an attachment.
     * Recommended usage: Ticket.Attachment.UploadAttachment
     * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/ticket-attachments/#upload-files
     * @param options Request options.
     */
    async uploadAttachment(options) {
        return this.Ticket.Attachment.uploadAttachment(options);
    }
    /**
  * Returns the comments added to the ticket.
  
  Each comment may include a `content_url` for an attachment or a `recording_url` for a voice comment that points to a file that may be hosted externally. For security reasons, take care not to inadvertently send Zendesk authentication credentials to third parties when attempting to access these files. See [Working with url properties](/documentation/ticketing/managing-tickets/working-with-url-properties).
  
  #### Pagination
  
  - Cursor pagination (recommended)
  - Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Sorting
  
  By default, comments are sorted by creation date in ascending order.
  
  When using cursor pagination, use the following parameter to change the sort order:
  
  | Name   | Type   | Required | Comments
  | ------ | ------ | -------- | --------
  | `sort` | string | no       | Possible values are "created_at" (ascending order) or "-created_at" (descending order)
  
  When using offset pagination, use the following parameters to change the sort order:
  
  | Name         | Type   | Required | Comments
  | ------------ | ------ | -------- | --------
  | `sort_order` | string | no       | One of `asc`, `desc`. Defaults to `asc`
  
  #### Allowed For
  
  * Agents
    
  * Alternative usage: Ticket.Comment.getComments
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/ticket_comments/#list-comments
  * @param options Request options.
  */
    async getTicketComments(options) {
        return this.Ticket.Comment.getComments(options);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Admins, Agents and Light Agents
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#list-users
  * @param options Request options.
  */
    async getAllUsers(options) {
        const { headers, errorStrategy, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", constructUrl(`/api/v2/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * The endpoint returns [user information](/api-reference/ticketing/users/users/) and an `authenticity_token`.
  
  #### Allowed For
  
  * Anonymous users
  
  #### Authenticity Token
  
  Zendesk API calls made by end users from a Zendesk help center must include `authenticity_token` in the `X-CSRF-Token` HTTP header. This helps prevent [cross-site request forgery (CSRF)](https://en.wikipedia.org/wiki/Cross-site_request_forgery) attacks.
  
  For an example using an authenticity token, see the AJAX request in the [Upgrading from Templating API v1](https://developer.zendesk.com/documentation/help_center/help-center-templates/v1#jquery) documentation.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#show-self
  * @param options Request options.
  */
    async getMyUser(options) {
        const { headers, errorStrategy } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", `/api/v2/users/me`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Accepts a comma-separated list of up to 100 user ids or external ids.
  
  #### Allowed For:
  
  * Agents
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#show-many-users
  * @param options Request options.
  */
    async getUsers(options) {
        const { headers, errorStrategy, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", constructUrl(`/api/v2/users/show_many`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Allowed For
  
  * Agents
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/users/users/#show-user
  * @param options Request options.
  */
    async getUser(options) {
        const { headers, errorStrategy, user_id } = options;
        const request = new Request("GET", `/api/v2/users/${encodeURIComponent(user_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/groups/group_memberships/#list-memberships
  * @param options Request options.
  */
    async getUsersByGroup(options) {
        const { headers, errorStrategy, group_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/groups/${encodeURIComponent(group_id)}/memberships`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents and End users.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/organizations/organization_memberships/#list-memberships
  * @param options Request options.
  */
    async getUsersByOrganization(options) {
        const { headers, errorStrategy, organization_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/organizations/${encodeURIComponent(organization_id)}/organization_memberships.json`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class OrganizationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents, with certain restrictions
  
  If the agent has a custom agent role that restricts their access to only users in their own organization, a 403 Forbidden error is returned. See [Creating custom agent roles](https://support.zendesk.com/hc/en-us/articles/203662026-Creating-custom-roles-and-assigning-agents#topic_cxn_hig_bd) in Zendesk help.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/organizations/organizations/#list-organizations
  * @param options Request options.
  */
    async getAllOrganizations(options) {
        const { headers, errorStrategy, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", constructUrl(`/api/v2/organizations`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents, with certain restrictions.
  
  If the agent has a custom agent role that restricts their access to only users in their own organization, a 403 Forbidden error is returned. See [Creating custom agent roles](https://support.zendesk.com/hc/en-us/articles/4408882153882-Creating-custom-roles-and-assigning-agents#topic_cxn_hig_bd) in Zendesk help.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/organizations/organizations/#list-organizations
  * @param options Request options.
  */
    async getOrganizationsByUser(options) {
        const { headers, errorStrategy, user_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/users/${encodeURIComponent(user_id)}/organizations.json`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Admins
  * Agents
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/groups/groups/#list-groups
  * @param options Request options.
  */
    async getAllGroups(options) {
        const { headers, errorStrategy, user_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/groups`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Admins and Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/groups/groups/#list-groups
  * @param options Request options.
  */
    async getGroupsByUser(options) {
        const { headers, errorStrategy, user_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/users/${encodeURIComponent(user_id)}/groups`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TicketGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Attachment = new TicketAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new TicketCommentGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * List Tickets
     * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
     * @param options Request options.
     */
    async getAllTickets(options) {
        const { headers, errorStrategy, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", constructUrl(`/api/v2/tickets`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create Ticket
     * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#create-ticket
     * @param options Request options.
     */
    async createTicket(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/api/v2/tickets`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a number of ticket properties though not the ticket comments. To get the comments, use [List Comments](/api-reference/ticketing/tickets/ticket_comments/#list-comments)
  
  #### Allowed For
  * Agents
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#show-ticket
  * @param options Request options.
  */
    async getTicket(options) {
        const { headers, errorStrategy, ticket_id } = options;
        const request = new Request("GET", `/api/v2/tickets/${encodeURIComponent(ticket_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Update Ticket
     * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#update-ticket
     * @param options Request options.
     */
    async updateTicket(options) {
        const { body, headers, errorStrategy, ticket_id } = options;
        const request = new Request("PUT", `/api/v2/tickets/${encodeURIComponent(ticket_id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Allowed For
  
  * Admins
  * Agents with permission to delete tickets
  
  Agent delete permissions are set in Support. See
  [Deleting tickets](https://support.zendesk.com/hc/en-us/articles/203690936)
  in the Support Help Center.
  
  #### Ticket deletion rate limit
  
  You can delete 400 tickets every 1 minute using this endpoint.
  The rate limiting mechanism behaves as described in
  [Rate limits](/api-reference/introduction/rate-limits/) in the API introduction.
  Zendesk recommends that you obey the Retry-After header values.
  To delete many tickets, you may use [Bulk Delete Tickets](/api-reference/ticketing/tickets/tickets/#bulk-delete-tickets).
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#delete-ticket
  * @param options Request options.
  */
    async deleteTicket(options) {
        const { headers, errorStrategy, ticket_id } = options;
        const request = new Request("DELETE", `/api/v2/tickets/${encodeURIComponent(ticket_id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Accepts a comma-separated list of ticket ids to return.
  
  This endpoint will return up to 100 tickets records.
  
  #### Allowed For
  * Agents
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#show-multiple-tickets
  * @param options Request options.
  */
    async getTickets(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/tickets/show_many`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByOrganization(options) {
        const { headers, errorStrategy, organization_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/organizations/${encodeURIComponent(organization_id)}/tickets`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByRequestedUser(options) {
        const { headers, errorStrategy, user_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/users/${encodeURIComponent(user_id)}/tickets/requested`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByCCdUser(options) {
        const { headers, errorStrategy, user_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/users/${encodeURIComponent(user_id)}/tickets/ccd`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByFollowedUser(options) {
        const { headers, errorStrategy, user_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/users/${encodeURIComponent(user_id)}/tickets/followed`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getTicketsByAssignedUser(options) {
        const { headers, errorStrategy, user_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/users/${encodeURIComponent(user_id)}/tickets/assigned`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * #### Pagination
  
  * Cursor pagination (recommended)
  * Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Allowed For
  
  * Agents.
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/tickets/#list-tickets
  * @param options Request options.
  */
    async getRecentTickets(options) {
        const { headers, errorStrategy, ...queryParams } = options !== null && options !== void 0 ? options : {};
        const request = new Request("GET", constructUrl(`/api/v2/tickets/recent`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TicketAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
    * Uploads a file that can be attached to a ticket comment. It doesn't attach the file to the comment. For details and examples, see [Attaching ticket comments with the API](/documentation/ticketing/using-the-zendesk-api/adding-ticket-attachments-with-the-api).
    
    The endpoint has a required `filename` query parameter. The parameter specifies what the file will be named when attached to the ticket comment (to give the agent more context about the file). The parameter does not specify the file on the local system to be uploaded. While the two names can be different, their file extensions must be the same. If they don't match, the agent's browser or file reader could give an error when attempting to open the attachment.
    
    The `Content-Type` header must contain a recognized MIME type that correctly describes the type of the uploaded file. Failing to send a recognized, correct type may cause undesired behavior. For example, in-browser audio playback may be interrupted by the browser's security mechanisms for MP3s uploaded with an incorrect type.
    
    Adding multiple files to the same upload is handled by splitting requests and passing the API token received from the first request to each subsequent request. The token is valid for 3 days.
    
    **Note**: Even if [private attachments](https://support.zendesk.com/hc/en-us/articles/204265396) are enabled in the Zendesk Support instance, uploaded files are visible to any authenticated user at the `content_URL` specified in the [JSON response](#json-format) until the upload token is consumed. Once a file is associated with a ticket or post, visibility is restricted to users with access to the ticket or post with the attachment.
    
    #### Allowed For
    
    * End users
      
    * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/ticket-attachments/#upload-files
    * @param options Request options.
    */
    async uploadAttachment(options) {
        const { headers, errorStrategy, body } = options;
        const fileBlob = new Blob(this.implementation, [body.content], { type: body.type });
        const token = body.token ? `&token=${encodeURIComponent(body.token)}` : "";
        const request = new Request("POST", `/api/v2/uploads.json?filename=${encodeURIComponent(body.filename)}${token}`, constructHeaders(body, { "Content-Type": body.type }), fileBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class TicketCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the comments added to the ticket.
  
  Each comment may include a `content_url` for an attachment or a `recording_url` for a voice comment that points to a file that may be hosted externally. For security reasons, take care not to inadvertently send Zendesk authentication credentials to third parties when attempting to access these files. See [Working with url properties](/documentation/ticketing/managing-tickets/working-with-url-properties).
  
  #### Pagination
  
  - Cursor pagination (recommended)
  - Offset pagination
  
  See [Pagination](/api-reference/introduction/pagination/).
  
  Returns a maximum of 100 records per page.
  
  #### Sorting
  
  By default, comments are sorted by creation date in ascending order.
  
  When using cursor pagination, use the following parameter to change the sort order:
  
  | Name   | Type   | Required | Comments
  | ------ | ------ | -------- | --------
  | `sort` | string | no       | Possible values are "created_at" (ascending order) or "-created_at" (descending order)
  
  When using offset pagination, use the following parameters to change the sort order:
  
  | Name         | Type   | Required | Comments
  | ------------ | ------ | -------- | --------
  | `sort_order` | string | no       | One of `asc`, `desc`. Defaults to `asc`
  
  #### Allowed For
  
  * Agents
    
  * Documentation: https://developer.zendesk.com/api-reference/ticketing/tickets/ticket_comments/#list-comments
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, ticket_id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/api/v2/tickets/${encodeURIComponent(ticket_id)}/comments`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
//# sourceMappingURL=index.js.map