/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { TicketsResponseAsResponse } from "../definitions/TicketsResponseAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { TicketCreateRequest } from "../definitions/TicketCreateRequest";
import { TicketResponseAsResponse } from "../definitions/TicketResponseAsResponse";
import { TicketUpdateRequest } from "../definitions/TicketUpdateRequest";
import { TicketUpdateResponseAsResponse } from "../definitions/TicketUpdateResponseAsResponse";
export interface GetAllTicketsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Lists tickets by external id. External ids don't have to be unique for each ticket. As a result, the request may return multiple tickets with the same external id.
     */
    external_id?: string;
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
}
type GetAllTicketsResponseOKType = TicketsResponseAsResponse;
export interface GetAllTicketsResponseOK extends GetAllTicketsResponseOKType {
}
export type GetAllTicketsResponseError = undefined;
export interface CreateTicketRequest extends HeadersOption, ErrorStrategyOption {
    body: TicketCreateRequest;
}
type CreateTicketResponseOKType = TicketResponseAsResponse;
export interface CreateTicketResponseOK extends CreateTicketResponseOKType {
}
export type CreateTicketResponseError = undefined;
export interface GetTicketRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the ticket
     */
    ticket_id: number;
}
type GetTicketResponseOKType = TicketResponseAsResponse;
export interface GetTicketResponseOK extends GetTicketResponseOKType {
}
export type GetTicketResponseError = undefined;
export interface UpdateTicketRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the ticket
     */
    ticket_id: number;
    body: TicketUpdateRequest;
}
type UpdateTicketResponseOKType = TicketUpdateResponseAsResponse;
export interface UpdateTicketResponseOK extends UpdateTicketResponseOKType {
}
export type UpdateTicketResponseError = undefined;
export interface DeleteTicketRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the ticket
     */
    ticket_id: number;
}
export type DeleteTicketResponseOK = undefined;
export type DeleteTicketResponseError = undefined;
export interface GetTicketsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Comma-separated list of ticket ids
     */
    ids: string;
    /**
     * the URL of the next page
     */
    next_page?: string;
    /**
     * the URL of the previous page
     */
    previous_page?: string;
}
type GetTicketsResponseOKType = TicketsResponseAsResponse;
export interface GetTicketsResponseOK extends GetTicketsResponseOKType {
}
export type GetTicketsResponseError = undefined;
export interface GetTicketsByOrganizationRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of an organization
     */
    organization_id: number;
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
}
type GetTicketsByOrganizationResponseOKType = TicketsResponseAsResponse;
export interface GetTicketsByOrganizationResponseOK extends GetTicketsByOrganizationResponseOKType {
}
export type GetTicketsByOrganizationResponseError = undefined;
export interface GetTicketsByRequestedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the user
     */
    user_id: number;
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
}
type GetTicketsByRequestedUserResponseOKType = TicketsResponseAsResponse;
export interface GetTicketsByRequestedUserResponseOK extends GetTicketsByRequestedUserResponseOKType {
}
export type GetTicketsByRequestedUserResponseError = undefined;
export interface GetTicketsByCCdUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the user
     */
    user_id: number;
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
}
type GetTicketsByCCdUserResponseOKType = TicketsResponseAsResponse;
export interface GetTicketsByCCdUserResponseOK extends GetTicketsByCCdUserResponseOKType {
}
export type GetTicketsByCCdUserResponseError = undefined;
export interface GetTicketsByFollowedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the user
     */
    user_id: number;
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
    /**
     * the URL of the next page
     */
    next_page?: string;
    /**
     * the URL of the previous page
     */
    previous_page?: string;
}
type GetTicketsByFollowedUserResponseOKType = TicketsResponseAsResponse;
export interface GetTicketsByFollowedUserResponseOK extends GetTicketsByFollowedUserResponseOKType {
}
export type GetTicketsByFollowedUserResponseError = undefined;
export interface GetTicketsByAssignedUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The id of the user
     */
    user_id: number;
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
}
type GetTicketsByAssignedUserResponseOKType = TicketsResponseAsResponse;
export interface GetTicketsByAssignedUserResponseOK extends GetTicketsByAssignedUserResponseOKType {
}
export type GetTicketsByAssignedUserResponseError = undefined;
export interface GetRecentTicketsRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
    /**
     * the URL of the next page
     */
    next_page?: string;
    /**
     * the URL of the previous page
     */
    previous_page?: string;
}
type GetRecentTicketsResponseOKType = TicketsResponseAsResponse;
export interface GetRecentTicketsResponseOK extends GetRecentTicketsResponseOKType {
}
export type GetRecentTicketsResponseError = undefined;
export {};
//# sourceMappingURL=ticket.d.ts.map