/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface UploadTicketAttachmentRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * Add a name to the file you want to upload to Zendesk, including the relevant file extension.
         *
         * For example: foo.png
         */
        filename: string;
        /**
         * Content to upload.
         */
        content: string | ArrayBuffer;
        type: string;
        /**
         * Adding multiple files to the same upload is handled by splitting requests and passing the API
         * token received from the first request to each subsequent request.
         * The token is valid for 3 days.
         */
        token?: string;
    };
}
interface UploadResponse {
    url: string;
    id: number;
    file_name: string;
    content_url: string;
    mapped_content_url: string;
    content_type: string;
    size: number;
    width: number;
    height: number;
    inline: boolean;
    deleted: boolean;
    malware_access_override: boolean;
    malware_scan_result: string;
}
interface UploadResponseWithThumbnails extends UploadResponse {
    thumbnails: UploadResponse;
}
export interface UploadTicketAttachmentResponseOK {
    upload: {
        token: string;
        expires_at: string;
        attachment: UploadResponseWithThumbnails;
        attachments: UploadResponseWithThumbnails[];
    };
}
export type UploadTicketAttachmentResponseError = undefined;
export {};
//# sourceMappingURL=attachment.d.ts.map