/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { TicketCommentsResponseAsResponse } from "../../definitions/TicketCommentsResponseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
export interface GetTicketCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the ticket
     */
    ticket_id: number;
    /**
     * Default is false. When true, inline images are also listed as attachments in the response
     */
    include_inline_images?: boolean;
    /**
     * Accepts "users". Use this parameter to list email CCs by side-loading users. Example: `?include=users`. **Note**: If the comment source is email, a deleted user will be represented as the CCd email address. If the comment source is anything else, a deleted user will be represented as the user name.
     */
    include?: string;
    /**
  * One of `id`, `updated_at`, `-id`, or `-updated_at`. The `-` denotes the sort will be descending.
  
  */
    sort?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.before_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[before]"?: string;
    /**
  * A [pagination cursor](/documentation/api-basics/pagination/paginating-through-lists-using-cursor-pagination) that tells the endpoint which page to start on. It should be a `meta.after_cursor` value from a previous request. Note: `page[before]` and `page[after]` can't be used together in the same request.
  
  */
    "page[after]"?: string;
    /**
  * Specifies how many records should be returned in the response. You can specify up to 100 records per page.
  
  */
    "page[size]"?: number;
}
type GetTicketCommentsResponseOKType = TicketCommentsResponseAsResponse;
export interface GetTicketCommentsResponseOK extends GetTicketCommentsResponseOKType {
}
export type GetTicketCommentsResponseError = undefined;
export {};
//# sourceMappingURL=comment.d.ts.map